# -*- encoding: utf-8 -*-
##############################################################################
#
#    Addition to OpenERP, Open Source Management Solution   
#    Copyright (C) 2012 Vertel. All Rights Reserved
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


import time
from datetime import datetime, timedelta

from osv import fields, osv
from crm import crm
import tools
import collections
import binascii
import tools
from tools.translate import _
from crm import wizard

AVAILABLE_STATES = [
    ('draft', 'New'),
    ('open', 'Active'),
    ('cancel', 'Not active'),
    ('done', 'Closed'),
    ('pending', 'Pending')
]


class hr_disrtict_report(osv.osv):
    """ Report from the district """
    _name = "hr.district.report"
    _description = "Report"
    _order = 'sequence'
    _columns = {
        'district_id': fields.many2one('hr.district', 'District Reference', required=True, ondelete='cascade', select=True, readonly=True, states={'draft':[('readonly',False)]}),
        'name': fields.char('Name', size=64, required=True, translate=True),
        'sequence': fields.integer('Sequence', help="Gives the sequence order when displaying a list of stages."),
        'user_id': fields.many2one('res.users', 'Responsible'),
        'Message': fields.text('Message'),
    }
    _defaults = {
        'sequence': 1,
    }
hr_disrtict_report()

class hr_district(osv.osv):
    _name = "hr.district"
    _description = "District"
    _order = "id desc"


    _columns = {
        'name': fields.char('Name', size=128, required=True),
        'report_ids': fields.one2many('hr.district.report', 'district_id', 'Reports', ),
        'active': fields.boolean('Active', help="If the active field is set to false, it will allow you to hide the disrtict without removing it."),
        'description': fields.text('Description'),
        'create_date': fields.datetime('Creation Date', readonly=True, select=True),
        'company_id': fields.many2one('res.company', 'Company'),
        'user_id': fields.many2one('res.users', 'Responsible'),
        'employee_ids': fields.one2many('hr.employee', 'job_id', 'Employees'),
        'state': fields.selection(AVAILABLE_STATES, 'State', size=16, readonly=True),
        'color': fields.integer('Color Index'),
    }

    _defaults = {
        'active': lambda *a: 1,
        'user_id':  lambda self, cr, uid, context: uid,
        'state': lambda *a: 'draft',
        'company_id': lambda s, cr, uid, c: s.pool.get('res.company')._company_default_get(cr, uid, 'crm.helpdesk', context=c),
        'color': 0,
    }


hr_district()


# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
